@@ -1,5 +1,5 @@
 #
-# $Id: Kafka.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
+# $Id$
 #
 # client::kafka Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6bd6acfc81d5 $',
+      revision => '$Revision$',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -61,6 +61,7 @@ sub brik_properties {
       optional_binaries => {
       },
       need_packages => {
+         freebsd => [ qw(p5-Tree-Trie) ],
       },
    };
 }
@@ -129,9 +130,17 @@ sub create_producer {
 
    my $kc = $self->create_connection or return;
 
+   # Doc:
+   # https://kafka.apache.org/documentation/#acks
+
    my $kp;
    eval {
-      $kp = Kafka::Producer->new(Connection => $kc);
+      $kp = Kafka::Producer->new(
+         Connection => $kc,
+         #RequiredAcks => $Kafka::WAIT_WRITTEN_TO_LOCAL_LOG,  # 1, default
+         RequiredAcks => $Kafka::BLOCK_UNTIL_IS_COMMITTED,  # -1, best
+         #RequiredAcks => $Kafka::NOT_SEND_ANY_RESPONSE,  # 0
+      );
    };
    if ($@) {
       chomp($@);
@@ -419,7 +428,7 @@ Metabrik::Client::Kafka - client::kafka Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2020, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
