@@ -1,5 +1,5 @@
 #
-# $Id: Redis.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
+# $Id$
 #
 # client::redis Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Service Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6bd6acfc81d5 $',
+      revision => '$Revision$',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -48,6 +48,7 @@ sub brik_properties {
          client_getname => [ ],
          list_databases => [ qw(database) ],
          list_keys => [ qw(database keys|OPTIONAL) ],
+         flushall => [ ],
       },
       require_modules => {
          'Redis' => [ ],
@@ -276,6 +277,12 @@ sub list_keys {
    return \@r;
 }
 
+sub flushall {
+   my $self = shift;
+
+   return $self->command('flushall');
+}
+
 1;
 
 __END__
@@ -286,7 +293,7 @@ Metabrik::Client::Redis - client::redis Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2020, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
