@@ -1,5 +1,5 @@
 #
-# $Id: Git.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
+# $Id$
 #
 # devel::git Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6bd6acfc81d5 $',
+      revision => '$Revision$',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -91,7 +91,7 @@ sub update_or_clone {
 
    $self->brik_help_run_undef_arg('update_or_clone', $repository) or return;
 
-   if (-d $directory) {
+   if (defined($directory) && -d $directory) {
       return $self->update($repository, $directory);
    }
 
@@ -108,7 +108,7 @@ Metabrik::Devel::Git - devel::git Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2020, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
