@@ -1,5 +1,5 @@
 #
-# $Id: Portscan.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
+# $Id$
 #
 # network::portscan Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Device);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6bd6acfc81d5 $',
+      revision => '$Revision$',
       tags => [ qw(unstable scan syn port synscan tcpscan) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -28,6 +28,7 @@ sub brik_properties {
          wait => [ qw(seconds) ],
          use_ipv6 => [ qw(0|1) ],
          src_ip => [ qw(ip_address) ],
+         filter_code_optimizer => [ qw(0|1) ],
          _nr => [ qw(INTERNAL) ],
       },
       attributes_default => { 
@@ -128,6 +129,7 @@ sub brik_properties {
          try => 2,
          wait => 5, # Wait 5 seconds for last packet
          use_ipv6 => 0,
+         filter_code_optimizer => 0,
       },
       commands => {
          estimate_runtime => [ qw($ip_list $port_list|OPTIONAL pps|OPTIONAL try|OPTIONAL) ],
@@ -348,6 +350,7 @@ sub tcp_syn_start_receiver {
    $listen_device ||= $self->listen_device;
 
    my $nr = Metabrik::Network::Read->new_from_brik_init($self) or return;
+   $nr->filter_code_optimizer($self->filter_code_optimizer);
 
    my $ip = '';
    if ($self->use_ipv6) {
@@ -380,11 +383,12 @@ sub tcp_syn_start_receiver {
       }
    }
 
-   $self->log->verbose("tcp_syn_start_receiver: using filter [$filter]");
-
    $nr->filter($filter);
    $nr->device($listen_device);
 
+   $self->log->verbose("tcp_syn_start_receiver: using filter [$filter] and ".
+      "device [$listen_device]");
+
    $nr->open or return;
  
    return $self->_nr($nr);
@@ -563,7 +567,7 @@ Metabrik::Network::Portscan - network::portscan Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2020, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
